==> icons-vue-1.1.0.tgz: package/README.md <==
# CoreUI Icons Vue

![NPM](https://img.shields.io/npm/v/@coreui/icons-vue/latest?style=flat&color=brightgreen)
![Downloads](https://img.shields.io/npm/dm/@coreui/icons.svg?style=flat-square)
![Vue](https://img.shields.io/badge/Vue-^2.6.10-brightgreen.svg)

## CIcon component

Dedicated component used to implement [CoreUI Icons SVG set](https://coreui.io/icons/) in Vue.js.

### Features

- Can load icons stored globally, directly passed or by source link,
- Can significantly reduce bundle size due to JavaScript named icons import,
- Full functionality of 'svg' html tag,
- Clean API

For component description visit [CIcon component documentation](https://coreui.io/vue/docs/components/icon)

### Installation

If you already have installed [CoreUI Vue component library](https://coreui.io/vue/docs) plugin, then you have CIcon component already installed, otherwise install package by:

```shell
npm install @coreui/icons-vue --save
```

### License

CoreUI Icons Free is free, open source, and GPL friendly. You can use it for
commercial projects, open source projects, or really almost whatever you want.

- Icons — CC BY 4.0 License
  - In the CoreUI Icons Free download, the CC BY 4.0 license applies to all icons packaged as .svg and .js files types.
- Fonts — SIL OFL 1.1 License
  - In the CoreUI Icons Free download, the SIL OLF license applies to all icons packaged as web and desktop font files.
- Code — MIT License
  - In the CoreUI Icons Free download, the MIT license applies to all non-font and non-icon files.

==> icons-vue-1.1.1.tgz: package/README.md <==
# CoreUI Icons Vue

![NPM](https://img.shields.io/npm/v/@coreui/icons-vue/latest?style=flat&color=brightgreen)
![Downloads](https://img.shields.io/npm/dm/@coreui/icons-vue.svg?style=flat-square)
![Vue](https://img.shields.io/npm/v/vue/latest?style=flat&color=brightgreen)

## CIcon component

Dedicated component used to implement [CoreUI Icons SVG set](https://coreui.io/icons/) in Vue.js.

### Features

- Can load icons in three ways:
  - stored globally in Vue root object,
  - directly passed SVG tag content,
  - source link to SVG file
- Greatly reduce icons bundle size, when imported as single icons,
- Full functionality of 'svg' html tag,
- Clean API

For component description visit [CIcon component documentation](https://coreui.io/vue/docs/components/icon)

### Installation

If you already have installed [CoreUI Vue component library](https://coreui.io/vue/docs) plugin, then you have CIcon component already installed, otherwise install package by:

```shell
npm install @coreui/icons-vue --save
```

### License

CoreUI Icons Free is free, open source, and GPL friendly. You can use it for
commercial projects, open source projects, or really almost whatever you want.

- Icons — CC BY 4.0 License
  - In the CoreUI Icons Free download, the CC BY 4.0 license applies to all icons packaged as .svg and .js files types.
- Fonts — SIL OFL 1.1 License
  - In the CoreUI Icons Free download, the SIL OLF license applies to all icons packaged as web and desktop font files.
- Code — MIT License
  - In the CoreUI Icons Free download, the MIT license applies to all non-font and non-icon files.
